@@ -1,6 +1,6 @@
 /* ncftp.h
  *
- * Copyright (c) 1996-2008 Mike Gleason, NcFTP Software.
+ * Copyright (c) 1996-2009 Mike Gleason, NcFTP Software.
  * All rights reserved.
  *
  */
@@ -13,10 +13,10 @@ extern "C"
 {
 #endif	/* __cplusplus */
 
-#define kLibraryVersion "@(#) LibNcFTP 3.2.2.2 (October 30, 2008)"
+#define kLibraryVersion "@(#) LibNcFTP 3.2.3 (July 23, 2009)"
 
 /* This is used to verify validty of the data passed in. */
-#define kLibraryMagic "LibNcFTP 3222"
+#define kLibraryMagic "LibNcFTP 3.2.3"
 
 #if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 	/* Includes for Windows */
@@ -269,9 +269,9 @@ typedef void (*FTPGetPassphraseProc)(const FTPCIPtr, FTPLineListPtr pwPrompt, ch
 typedef struct FTPConnectionInfo {
 	char magic[16];				/* Don't modify this field. */
 	
-	char host[64];				/* REQUIRED input parameter. */
-	char user[64];				/* OPTIONAL input parameter. */
-	char pass[64];				/* OPTIONAL input parameter. */
+	char host[128];				/* REQUIRED input parameter. */
+	char user[128];				/* OPTIONAL input parameter. */
+	char pass[256];				/* OPTIONAL input parameter. */
 	char acct[64];				/* OPTIONAL input parameter. */
 	unsigned int passIsEmpty;		/* OPTIONAL input parameter. */
 	unsigned int port;			/* OPTIONAL input parameter. */
@@ -282,6 +282,7 @@ typedef struct FTPConnectionInfo {
 	int lastFTPCmdResultNum;		/* You may modify this if you want. */
 
 	FILE *debugLog;				/* OPTIONAL input parameter. */
+	int debugTimestamping;			/* OPTIONAL input parameter. */
 	FTPLogProc debugLogProc;		/* OPTIONAL input parameter. */
 
 	unsigned int xferTimeout;		/* OPTIONAL input parameter. */
@@ -355,6 +356,8 @@ typedef struct FTPConnectionInfo {
 	int hasSIZE;				/* Do not modify this field. */
 	int hasMDTM;				/* Do not modify this field. */
 	int hasMDTM_set;			/* Do not modify this field. */
+	int hasMFMT;				/* Do not modify this field. */
+	int hasMFF;				/* Do not modify this field. */
 	int hasREST;				/* Do not modify this field. */
 	int hasNLST_a;				/* Do not modify this field. */
 	int hasNLST_d;				/* Do not modify this field. */
@@ -769,9 +772,9 @@ int WinStat64(const char *const path, struct WinStat64 *const stp);
 
 /* The following block may be changed by configure script */
 #ifndef Stat
-#define Stat stat64    /* set by configure at 2008-07-15 10:17:24 */
-#define Lstat lstat64    /* set by configure at 2008-07-15 10:17:24 */
-#define Fstat fstat64    /* set by configure at 2008-07-15 10:17:24 */
+#define Stat stat    /* set by configure at 2009-07-23 15:20:53 */
+#define Lstat lstat    /* set by configure at 2009-07-23 15:20:53 */
+#define Fstat fstat    /* set by configure at 2009-07-23 15:20:53 */
 #endif
 
 #define kFtwNoAutoGrowButContinue (-1)
